<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 20, 2020
 */

/**
 * Application is a copy of a policy, and is resource specific
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Backups_Plan_Application
{
    const STATUS_RUNNING = 'running';

    const ID = 'id';
    const ENABLED = 'enabled';
    const NAME = 'name';

    private $_id;
    private $_policy_type;
    private $_policy_id;
    private $_policy;
    private $_agent_id;
    private $_created_at;
    private $_updated_at;
    private $_context;
    private $_running_state;
    private $_running_progress;
    private $_last_success_run;
    private $_last_run_time;
    private $_next_run_time;
    private $_status;



    /**
     * Constructor.
     *
     * @param array $api_res_application
     */
    public function __construct(array $api_res_application)
    {
        $this->_id = $api_res_application['id'];
        $this->_created_at = $api_res_application['created_at'];
        $this->_updated_at = $api_res_application['updated_at'];
        $this->_deleted_at = $api_res_application['deleted_at'];
        $this->_context = $api_res_application['context']; // includes resource id, type of resource
        $this->_policy = $api_res_application['policy'];
        $this->_policy_id = $this->_policy['id'];
        $this->_policy_type = $this->_policy['type'];
        $this->_agent_id = $api_res_application['agent_id'];

        $this->_running_state = $api_res_application['running']['state'];
        $this->_running_progress = $api_res_application['running']['progress'];

        $this->_last_success_run = $api_res_application['last_success_time'];
        $this->_last_run_time = $api_res_application['last_run_time'];
        $this->_next_run_time = $api_res_application['next_run_time'];
        $this->_status = $api_res_application['status'];
    }

    /**
     * Get policy id
     *
     * @return string
     */
    public function getPolicyId(): string
    {
        return $this->_policy_id;
    }

    /**
     * Get policy type
     *
     * @return string
     */
    public function getPolicyType(): string
    {
        return $this->_policy_type;
    }

    /**
     * Get id.
     *
     * @return string
     */
    public function getId()
    {
        return $this->_id;
    }

    /**
     * Get next run time
     *
     * @return string|null
     */
    public function getNextRunTime()
    {
        return $this->_next_run_time;
    }

    /**
     * @return string|null
     */
    public function getLastRunTime()
    {
        return $this->_last_run_time;
    }

    /**
     * @return string|null
     */
    public function getLastSuccessRunTime()
    {
        return $this->_last_success_run;
    }

    /**
     * E.g. "ok"
     *
     * @return string|null
     */
    public function getStatus()
    {
        return $this->_status;
    }

    /**
     * get state
     *
     * @return array
     */
    public function getState(): array
    {
        return array(
            'status' => $this->_status,
            'running_state' => $this->_running_state,
            'running_progress' => $this->_running_progress
        );
    }

    /**
     * Check if backup is in progress
     *
     * @return boolean
     */
    public function backupInProgress(): bool
    {
        return $this->_status === 'running';
    }
}
