<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2022 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Jul 01, 2022
 */


class ResourceMachineTest extends IWorx_Framework_TestCase
{
    /**
     * Test getName
     */
    public function testGetName()
    {
        $expected = 'acronis.6.13.1.2.malin.iwx.io';
        $ResourceMachine = $this->_getSut();
        $this->assertSame($expected, $ResourceMachine->getName(), 'Expected resource name: ' . $expected);
    }

    /**
     * Test getInstanceId
     */
    public function testGetInstanceId()
    {
        $expected = '6e5cc601-e212-4a39-b823-69f0cbf9fdeb';
        $ResourceMachine = $this->_getSut();
        $this->assertSame($expected, $ResourceMachine->getInstanceId(), 'Expected instance id: ' . $expected);
    }

    /**
     * Test getAgentId
     */
    public function testGetAgentId()
    {
        $expected = 'c6fa2e7b-481d-4bfe-a971-c1f79a6c492a';
        $ResourceMachine = $this->_getSut();
        $this->assertSame($expected, $ResourceMachine->getAgentId(), 'Expected agent id: ' . $expected);
    }

    /**
     * Test getAgentDetails
     */
    public function testGetAgentDetails()
    {
        $expected = $this->_getExpectedAgentDetails();
        $ResourceMachine = $this->_getSut();
        $this->assertSame($expected, $ResourceMachine->getAgentDetails(), 'Agent details not same as expected!');
    }

    /**
     * Get system under test
     */
    private function _getSut(): Model_Resources_ResourceMachine
    {
        $json = file_get_contents(__DIR__ . '/../resources/api_mock_response/resource.json');
        $mock_api_res = json_decode($json, true);

        return new Model_Resources_ResourceMachine($mock_api_res);
    }

    /**
     * Get expected agent details
     */
    private function _getExpectedAgentDetails()
    {
        return array(
            "components" => ["x64LinuxAgent"],
            "features"=> ["x64LinuxAgent"],
            "os_family"=> "Linux",
            "os_name"=> "Linux: CentOS Linux release 7.9.2009 (Core)",
            "os_arch"=> "x64",
            "os_caps"=> 2,
            "os_product_type" => 3,
            "os_service_pack" => 0,
            "os_suite_mask"=> 0,
            "sku"=> 0,
            "os_version_major"=> 7,
            "os_version_minor"=> 9,
            "mac_addresses"=> ["0A:51:F4:2A:57:1A"],
            "memory_size"=> 3910414336,
            "processor_frequency"=> 2499,
            "processor_name"=> 2499,
            "chassis"=> "other",
            "vm_host_type"=> "kvm",
            "esx_address"=> "",
            "residental_addresses"=> ["172.31.42.84","172.31.45.83"],
            "inside_virtual"=> 1,"tz_offset"=> -240,
            "version"=> "15.0.29896",
            "enabled"=> 1,
            "is_online"=> 1
        );
    }
}
